@@ -11,8 +11,8 @@ package Spreadsheet::Edit::IO;
 
 # Allow "use <thismodule. VERSION ..." in development sandbox to not bomb
 { no strict 'refs'; ${__PACKAGE__."::VER"."SION"} = 998.999; }
-our $VERSION = '3.025'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
-our $DATE = '2023-06-09'; # DATE from Dist::Zilla::Plugin::OurDate
+our $VERSION = '3.026'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+our $DATE = '2023-06-11'; # DATE from Dist::Zilla::Plugin::OurDate
 
 # This module is derived from the old never-released Text:CSV::Spreadsheet
 
@@ -453,6 +453,9 @@ sub _openlibre_path() {
               if ($path) {
                 $prefix->subsumes($path) or oops dvis '$prefix $path';
                 my $subpath = path($path)->relative($prefix);
+                # Ignore major version larger than 9.  There is a known-bad 24.x
+                # dev build out there...
+                next if $subpath =~ /(^|\D)[0-9][0-9]/;
                 if (_cmp_subpaths($subpath, $results{$o_l}{subpath}) >= 0) {
                   @{$results{$o_l}}{qw/path subpath/} = ($path, $subpath);
                   # We found where installations are, don't look deeper
